package com.gic.evaluate.service.outer.impl;

import com.alibaba.fastjson.JSON;
import com.gic.api.base.commons.ServiceResponse;
import com.gic.commons.util.DateUtil;
import com.gic.commons.util.EntityUtil;
import com.gic.enterprise.response.EnterpriseServiceResponse;
import com.gic.evaluate.constant.Constants;
import com.gic.evaluate.dto.EvaluateMsgLogDTO;
import com.gic.evaluate.entity.TabEvaluateMsgLog;
import com.gic.evaluate.entity.TabEvaluateOrderConfig;
import com.gic.evaluate.service.EvaluateMsgLogApiService;
import com.gic.evaluate.service.EvaluateMsgLogService;
import com.gic.evaluate.service.EvaluateOrderConfigService;
import org.apache.logging.log4j.LogManager;
import org.apache.logging.log4j.Logger;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.Date;

/**
 *
 * @Description:
 * @author zhiwj
 * @date 2020/2/6 13:40
 */
@Service("evaluateMsgLogApiService")
public class EvaluateMsgLogApiServiceImpl implements EvaluateMsgLogApiService {

    private Logger logger = LogManager.getLogger(EvaluateMsgLogApiServiceImpl.class);
    
    @Autowired
    private EvaluateMsgLogService evaluateMsgLogService;
    @Autowired
    private EvaluateOrderConfigService evaluateOrderConfigService;
    
    @Override
    public ServiceResponse<Void> saveEvaluateMsgLog(EvaluateMsgLogDTO evaluateMsgLogDTO) {
        logger.info("保存评价提醒日志信息：{}", JSON.toJSONString(evaluateMsgLogDTO));
        TabEvaluateMsgLog oldMsgLog = evaluateMsgLogService.getByOrderId(evaluateMsgLogDTO.getOrderId());
        if (oldMsgLog != null) {
            logger.info("该订单已存在, orderId:{}", evaluateMsgLogDTO.getOrderId());
            return EnterpriseServiceResponse.success();
        }
        TabEvaluateMsgLog evaluateMsgLog = EntityUtil.changeEntityByJSON(TabEvaluateMsgLog.class, evaluateMsgLogDTO);

        TabEvaluateOrderConfig evaluateOrderConfig = evaluateOrderConfigService.getEvaluateOrderConfig(evaluateMsgLogDTO.getEnterpriseId());
        Date now = new Date();

        if (evaluateOrderConfig.getMindHour() != null) {
            // 第一次提醒
            Date sendTime = DateUtil.stringToDate(DateUtil.dateToString(DateUtil.addNumForDay(now, evaluateOrderConfig.getMindHour())) + " 19:00:00");
            evaluateMsgLog.setFirstSendTime(sendTime);
            evaluateMsgLog.setFirstStatus(1);
        }
        if (evaluateOrderConfig.getRemindDay() != null) {
            // 第二次提醒
            Date sendTime = DateUtil.stringToDate(DateUtil.dateToString(DateUtil.addNumForDay(now, evaluateOrderConfig.getRemindDay())) + " 19:00:00");
            evaluateMsgLog.setSecondSendTime(sendTime);
            evaluateMsgLog.setSecondStatus(1);
        }
        if (Constants.OPEN.equals(evaluateOrderConfig.getReview()) && evaluateOrderConfig.getReviewRemind() != null) {
            // 追评提醒
            Date date = DateUtil.addNumForDay(DateUtil.addNumForDay(now, evaluateOrderConfig.getEvaluateLimitday()), evaluateOrderConfig.getReviewRemind());
            Date sendTime = DateUtil.stringToDate(DateUtil.dateToString(date) + " 19:00:00");
            evaluateMsgLog.setReviewSendTime(sendTime);
            evaluateMsgLog.setReviewStatus(1);
        }
        evaluateMsgLogService.save(evaluateMsgLog);
        return EnterpriseServiceResponse.success();
    }

    @Override
    public ServiceResponse<Void> timerSendMemberMessage() {
        return null;
    }

    @Override
    public ServiceResponse<Void> queueSendMemberMessage(String enterpriseId) {
        return null;
    }
}
